DependencyConfig class

Annotations
  • @freezed

Constructors

DependencyConfig({required ImportableType type, required ImportableType typeImplementation, required InjectionModuleConfig injectionModuleConfig, @Default.new(DependencyType.factory) DependencyType dependencyType, @Default.new([]) List<InjectedDependency> dependencies, @Default.new([]) List<String> environments, @Default.new(false) bool isAsync, @Default.new(false) bool preResolve, String? instanceName, String? constructorName, ExternalModuleConfig? externalModuleConfig, DisposeFunctionConfig? disposeFunctionConfig})
const
factory
DependencyConfig.fromJson(Map<String, Object?> json)
factory

Properties

constructorName → String?
no setterinherited
copyWith → $DependencyConfigCopyWith<DependencyConfig>
no setterinherited
dependencies → List<InjectedDependency>
no setterinherited
dependencyType → DependencyType
no setterinherited
disposeFunctionConfig → DisposeFunctionConfig?
no setterinherited
environments → List<String>
no setterinherited
externalModuleConfig → ExternalModuleConfig?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
injectionModuleConfig → InjectionModuleConfig
no setterinherited
instanceName → String?
no setterinherited
isAsync → bool
no setterinherited
isFromExternalModule → bool
no setter
namedDependencies → List<InjectedDependency>
no setter
positionalDependencies → List<InjectedDependency>
no setter
preResolve → bool
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → ImportableType
no setterinherited
typeImplementation → ImportableType
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited