DisposeFunctionConfig class

Annotations
  • @freezed

Constructors

DisposeFunctionConfig({required String name, @Default.new(false) bool isInstance, ImportableType? importableType})
const
factory
DisposeFunctionConfig.fromJson(Map<String, Object?> json)
factory

Properties

copyWith → $DisposeFunctionConfigCopyWith<DisposeFunctionConfig>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
importableType → ImportableType?
no setterinherited
isInstance → bool
no setterinherited
name → String
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited